#
# spec file for package libretro-pcsx-rearmed
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libretro-pcsx-rearmed
Version:        0~git20200507
Release:        lp152.1.1
Summary:        ARM optimized PCSX core for PlayStation emulation
License:        GPL-2.0-only
URL:            http://www.retroarch.com
Source:         %{name}-%{version}.tar.xz

BuildRequires:  gcc-c++
BuildRequires:  make

Provides:       libretro-pcsx_rearmed = %{version}
Obsoletes:      libretro-pcsx_rearmed < %{version}

%description
PCSX ReARMed is yet another PCSX fork based on the PCSX-Reloaded project, which
itself contains code from PCSX, PCSX-df and PCSX-Revolution. This version is ARM
architecture oriented and features MIPS->ARM recompiler by Ari64, NEON GTE code
and more performance improvements. It was created for Pandora handheld, but should
be usable on other devices after some code adjustments (N900, GPH Wiz/Caanoo,
PlayBook versions are also available).

PCSX ReARMed features ARM NEON GPU by Exophase, that in many cases produces pixel
perfect graphics at very high performance. There is also Una-i's GPU plugin from
PCSX4ALL project, and traditional P.E.Op.S. one.

This package is for RetroArch/Libretro front-end.

%prep
%setup -q

%build
make -f Makefile.libretro DYNAREC=lightrec

%install
mkdir -p %{buildroot}%{_libdir}/libretro
cp pcsx_rearmed_libretro.so %{buildroot}%{_libdir}/libretro

%files
%dir %{_libdir}/libretro
%{_libdir}/libretro/pcsx_rearmed_libretro.so

%changelog
* Sun May 10 2020 i@guoyunhe.me
- Update to version 0~git20200507:
  * Move guncon options to update_variables
  * Fixup update_variables
  * Fix some edge case where core can freeze upon loading content
  * Automatically disable lightrec when no bios is present, take 2
  * Revert "Automatically disable lightrec when no bios is present"
  * Automatically disable lightrec when no bios is present
  * cdriso: fix a disk switching deadlock
  * Fixed bug where MSB of a 15-bit BGR color could corrupt green value. Also added documentation.
  * Clean up indentation / add comments for assembly functions
  * (3DS) Disable dithering by default
  * Preserve uSrc MSB across lighting and blending
  * WIP: Add ARM-assembly versions of lighting and blending
  * [3DS] Tweak compile-time options to increase performance
  * Add async CD access
  * Revert "(3DS) Set pthread stack size to 12MB - possible solution for crashes"
  * Fix dynarec crashes on 3DS
  * Fix second instance runahead without breaking reset
  * Revert "Use a more lightweight reset method for lightrec"
  * Use a more lightweight reset method for lightrec
  * Add fallback addresses so second instance runahead can work
  * (3DS) Set pthread stack size to 12MB - possible solution for crashes
  * Replace existing gte_divider with MAME's version
  * Silence some unused variable warnings
  * Take out this override for OSX
  * Buildfix
  * gte_neon: fix compile under clang's assembler
  * add some missing license headers
  * gte_neon: fix compile under clang's assembler
  * License these files as MIT
  * menu: fix a buffer overflow
  * cdrom: add missing BCD->int convert in cdrFreeze()
  * gpulib: fix out-of-bounds reads in do_cmd_buffer()
  * Fix corrupted memory card saves when using HLE
* Mon Feb 10 2020 i@guoyunhe.me
- Update to version 0~git20200209:
  * Update Android.mk
  * (Android) Aarch64/x86/x64 now has lightrec support
  * Buildfix for LLVM
  * OSX should use lightrec
  * Fix build
  * Update Makefile.libretro
  * Update psxmem.c
  * (NEON GPU) Don't hide this for non-ARM
  * Start getting NEON GPU to work on non-Arm
  * License this MIT - should be compatible with everything
  * Update .travis.yml
  * Update Makefile.libretro
  * Fix Linux build
  * cdrom: add missing BCD->int convert in cdrFreeze()
  * gpulib: fix out-of-bounds reads in do_cmd_buffer()
  * Add support for the Lightrec dynarec
  * pcsxmem: mmap RAM/BIOS/scratchpad to better locations
  * git subrepo clone (merge) https://github.com/witwall/mman-win32 deps/mman
  * git subrepo clone https://github.com/pcercuei/lightrec.git deps/lightrec
  * git subrepo clone https://git.savannah.gnu.org/git/lightning.git deps/lightning
* Fri Feb  7 2020 Yunhe Guo <i@guoyunhe.me>
- Initial version
